{%- if filetype_loop == 0 %}Claimed At,License Expiration Date,MAC Address,Model,Name,Network Id,Order Number,Product Type,Serial Number,Tags
{%- for fact in device %}
{{ fact.claimedAt }},{{ fact.licenseExpirationDate }},{{ fact.mac }},{{ fact.model }},{{ fact.name }},{{ fact.networkId }},{{ fact.orderNumber }},{{ fact.productType }},{{ fact.serial }},{%- for tag in fact.tags %}{{ tag }}{%- endfor %}
{%- endfor %}
{%- else %}
{%-     if filetype_loop == 1 %}
# Meraki Organization Devices
| Claimed At | License Expiration Date | MAC Address | Model | Name | Network Id | Order Number | Product Type | Serial Number | Tags |
| ---------- | ----------------------- | ----------- | ----- | ---- | ---------- | ------------ | ------------ | ------------- | ---- |
{%- for fact in device %}
| {{ fact.claimedAt }} | {{ fact.licenseExpirationDate }} | {{ fact.mac }} | {{ fact.model }} | {{ fact.name }} | {{ fact.networkId }} | {{ fact.orderNumber }} | {{ fact.productType }} | {{ fact.serial }} | {%- for tag in fact.tags %}{{ tag }}{%- endfor %} |
{%- endfor %}
{%-     else %}
{%-         if filetype_loop == 2 %}
<html>
<head>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"></script>
    <script src="https://cdn.datatables.net/1.11.4/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/dataTables.buttons.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/jszip/3.1.3/jszip.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/pdfmake.min.js"></script>
    <script src="https://cdnjs.cloudflare.com/ajax/libs/pdfmake/0.1.53/vfs_fonts.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.html5.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.print.min.js"></script>
    <script src="https://cdn.datatables.net/colreorder/1.5.4/js/dataTables.colReorder.min.js"></script>
    <script src="https://cdn.datatables.net/buttons/2.0.0/js/buttons.colVis.min.js"></script>
    <script src="https://cdn.datatables.net/keytable/2.6.4/js/dataTables.keyTable.min.js"></script>
    <script src="https://cdn.datatables.net/select/1.3.3/js/dataTables.select.min.js"></script>
    <script src="https://cdn.datatables.net/fixedheader/3.1.9/js/dataTables.fixedHeader.min.js"></script>
    <link rel="stylesheet" href="https://cdn.datatables.net/fixedheader/3.1.9/css/fixedHeader.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/select/1.3.3/css/select.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/keytable/2.6.4/css/keyTable.dataTables.min.css">
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.4/css/jquery.dataTables.min.css">
</head>
<body>
<h1>Meraki Organization Devices</h1>
<table id = "organizations">
  <thead>
    <tr>
      <th>Claimed At</th>
      <th>License Expiration Date</th>
      <th>MAC Address</th>
      <th>Model</th>
      <th>Name</th>
      <th>Network Id</th>
      <th>Order Number</th>
      <th>Product Type</th>
      <th>Serial Number</th>
      <th>Tags</th>
    </tr>
  </thead>
  <tbody>
{%- for fact in device %}
  <tr>
    <td>{{ fact.claimedAt }}</td>
    <td>{{ fact.licenseExpirationDate }}</td>
    <td>{{ fact.mac }}</td>
    <td>{{ fact.model }}</td>
    <td>{{ fact.name }}</td>
    <td>{{ fact.networkId }}</td>
    <td>{{ fact.orderNumber }}</td>
    <td>{{ fact.productType }}</td>
    <td>{{ fact.serial }}</td>
    <td>{%- for tag in fact.tags %}{{ tag }}{%- endfor %}</td>
  </tr>
{%- endfor %}
  </tbody>
</table>
<script type = "text/javascript">
  $(document).ready(function(){
    $('#organizations thead tr')
    .clone(true)
    .addClass('filters')
    .appendTo('#organizations thead');

    var table = $('#organizations').DataTable({
        keys: true,
        dom: 'Bfrtip',
        lengthMenu: [
            [ 10, 25, 50, -1 ],
            [ '10 rows', '25 rows', '50 rows', 'Show all' ]
        ],
        buttons: [
        'pageLength','colvis','copy', 'csv', 'excel', 'pdf', 'print'
        ],
        colReorder: true,
        select: true,            
        orderCellsTop: true,
        fixedHeader: true,
        initComplete: function () {
        var api = this.api();

        // For each column
        api
            .columns()
            .eq(0)
            .each(function (colIdx) {
                // Set the header cell to contain the input element
                var cell = $('.filters th').eq(
                    $(api.column(colIdx).header()).index()
                );
                var title = $(cell).text();
                $(cell).html('<input type="text" placeholder="' + title + '" />');

                // On every keypress in this input
                $(
                    'input',
                    $('.filters th').eq($(api.column(colIdx).header()).index())
                )
                    .off('keyup change')
                    .on('keyup change', function (e) {
                        e.stopPropagation();

                        // Get the search value
                        $(this).attr('title', $(this).val());
                        var regexr = '({search})'; //$(this).parents('th').find('select').val();

                        var cursorPosition = this.selectionStart;
                        // Search the column for that value
                        api
                            .column(colIdx)
                            .search(
                                this.value != ''
                                    ? regexr.replace('{search}', '(((' + this.value + ')))')
                                    : '',
                                this.value != '',
                                this.value == ''
                            )
                            .draw();

                        $(this)
                            .focus()[0]
                            .setSelectionRange(cursorPosition, cursorPosition);
                    });
            });
    },
});
});        
</script>
</body></html>
{%-         else %}
# Meraki Organization Devices
{%- for fact in device %}
## {{ fact.name }}
### ID: {{ fact.networkId }}
### Claimed At: {{ fact.claimedAt }}
### License Expiration Date: {{ fact.licenseExpirationDate }}
### MAC Address: {{ fact.mac }}
### Model: {{ fact.model }}
### Order Number: {{ fact.orderNumber }}
### Product Type: {{ fact.productType }}
### Serial NumbeR: {{ fact.serial }}
### Tags
{%- for tag in fact.tags %}
#### {{ tag }}
{%- endfor %}
{%- endfor %}
{% endif %}{% endif %}{% endif %}